pub enum MrtrRetry {
InputRequired(MrtrInputRequired),
Complete(MrtrCompletedInputs),
}Expand description
The outcome of consuming one final MRTR retry.
Variants
InputRequired(MrtrInputRequired)
More client input is needed; only unsatisfied keys are reissued with a fresh request state.
Complete(MrtrCompletedInputs)
All currently requested input values were accepted and type-checked.