pub struct MrtrInputRequired { /* private fields */ }Expand description
A final input_required result emitted by the server.
Safe server construction always includes a protected request state. An empty request map is emitted as a state-only result, which permits an immediate retry without manufacturing an empty input map.
Implementations
Sourceimpl MrtrInputRequired
impl MrtrInputRequired
Sourcepub fn input_requests(&self) -> Option<&MrtrInputRequests>
pub fn input_requests(&self) -> Option<&MrtrInputRequests>
Returns the embedded request map, if this result needs client input.