pub struct RequestSender { /* private fields */ }Expand description
Sends server-to-client requests through the transport.
This struct provides a way to send requests to the client and await responses.
It works in conjunction with PendingRequests to track in-flight requests.
Implementations
Sourceimpl RequestSender
impl RequestSender
Sourcepub fn new(pending: Arc<PendingRequests>, send_fn: TransportSendFn) -> Self
pub fn new(pending: Arc<PendingRequests>, send_fn: TransportSendFn) -> Self
Creates a new request sender.
Sourcepub fn send_request<T: DeserializeOwned>(
&self,
cx: &Cx,
method: &str,
params: Value,
) -> McpResult<T>
pub fn send_request<T: DeserializeOwned>( &self, cx: &Cx, method: &str, params: Value, ) -> McpResult<T>
Sends a request to the client and waits for a response.
Errors
Returns an error if:
- The transport send fails
- The request times out (based on budget)
- The client returns an error response
- The connection is closed