pub enum ServerLaunchPolicyError {
NonUnicode,
InvalidValue,
FeatureUnavailable,
}Expand description
The selected launch policy is malformed, not valid Unicode, or unavailable in the compiled server feature set.
Variants
NonUnicode
The reserved launch setting was present but was not valid Unicode.
InvalidValue
The reserved launch setting was not one of the exact supported values.
The selected policy requires a server feature that is not compiled in.