pub enum ExtensionHandlerInvocationError {
RegistryNotFrozen,
Protocol(ExtensionDispatchError),
HandlerNotFound(ExtensionHandlerKey),
RequestEnvelopeRequired(ExtensionHandlerKey),
Handler(McpError),
}Expand description
Failure while admitting or invoking a typed extension handler.
Variants
RegistryNotFrozen
Invocation is unavailable until the capability and handler registries are frozen together.
Protocol(ExtensionDispatchError)
The current exchange did not admit this capability and client-to-server request method.
HandlerNotFound(ExtensionHandlerKey)
No handler was registered for an otherwise admitted extension request method.
RequestEnvelopeRequired(ExtensionHandlerKey)
A descriptor-owned extension request was sent as an id-less notification.
Handler(McpError)
The admitted typed handler returned an MCP error.