pub enum OAuthError {
InvalidRequest(String),
InvalidClient(String),
InvalidGrant(String),
UnauthorizedClient(String),
UnsupportedGrantType(String),
InvalidScope(String),
ServerError(String),
TemporarilyUnavailable(String),
AccessDenied(String),
UnsupportedResponseType(String),
}Expand description
OAuth error types following RFC 6749.
Variants
InvalidRequest(String)
The request is missing a required parameter or is otherwise malformed.
InvalidClient(String)
Client authentication failed.
InvalidGrant(String)
The authorization grant or refresh token is invalid.
The client is not authorized to use this grant type.
UnsupportedGrantType(String)
The grant type is not supported.
InvalidScope(String)
The requested scope is invalid or unknown.
ServerError(String)
The authorization server encountered an unexpected condition.
The authorization server is temporarily unavailable.
AccessDenied(String)
Access denied by the resource owner.
UnsupportedResponseType(String)
The response type is not supported.
Implementations
Sourceimpl OAuthError
impl OAuthError
Sourcepub fn error_code(&self) -> &'static str
pub fn error_code(&self) -> &'static str
Returns the OAuth error code.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the error description.