pub enum OAuthHttpRouteConfigurationError {
InvalidPublicEndpointBase,
IssuerOriginMismatch,
}Expand description
A public OAuth HTTP route configuration was unsafe or ambiguous.
Variants
InvalidPublicEndpointBase
The configured endpoint base was not a canonical HTTPS URL.
IssuerOriginMismatch
The endpoint base did not share the configured OAuth issuer origin.