pub struct ProgressNotificationSender<F>{ /* private fields */ }Expand description
A notification sender that sends progress notifications via a callback.
This is the server-side implementation used to send notifications back to the client during handler execution.
Implementations
Sourceimpl<F> ProgressNotificationSender<F>
impl<F> ProgressNotificationSender<F>
Sourcepub fn new(marker: ProgressMarker, send_fn: F) -> Self
pub fn new(marker: ProgressMarker, send_fn: F) -> Self
Creates a new progress notification sender.
Sourcepub fn into_reporter(self) -> ProgressReporterwhere
Self: 'static,
pub fn into_reporter(self) -> ProgressReporterwhere
Self: 'static,
Creates a progress reporter from this sender.