pub struct TokenAuthProvider { /* private fields */ }Expand description
Token-based authentication provider.
Implementations
Sourceimpl TokenAuthProvider
impl TokenAuthProvider
Sourcepub fn new<V: TokenVerifier + 'static>(verifier: V) -> Self
pub fn new<V: TokenVerifier + 'static>(verifier: V) -> Self
Creates a new token auth provider with the given verifier.
Sourcepub fn with_missing_token_error(self, error: McpError) -> Self
pub fn with_missing_token_error(self, error: McpError) -> Self
Overrides the error returned when a token is missing.